@@ -17,13 +17,16 @@
 //!
 //! If you went to rise your own error message, [`indicated_msg`] might be a good choice.
 //!
-//! The anchor system is implemented by using [`std::rc::Rc`] and [`std::sync::Arc`] as inner handler,
-//! please see [`AnchorVisitor`].
+//! The anchor system [`AnchorBase`] is implemented by using [`alloc::rc::Rc`] and [`alloc::sync::Arc`] as inner handler.
+//! Additionally, [`anchors!`] macro can used to create anchor visitor by yourself.
+#![no_std]
+extern crate alloc;
+extern crate core;
+pub use crate::anchors::*;
 pub use crate::dumper::dump;
 pub use crate::indicator::*;
 pub use crate::node::*;
 pub use crate::parser::{parse, parse_arc};
-pub use crate::visitor::*;
 pub use crate::yaml::*;
 
 /// Create [`Node`] items literally.
@@ -51,6 +54,8 @@ pub use crate::yaml::*;
 /// assert_eq!(node!(YamlBase::Null), node!(null));
 /// assert_eq!(node!(YamlBase::Anchor("x".into())), node!(*"x"));
 /// ```
+///
+/// For [`ArcNode`], please use [`node_arc!`], which has same API.
 #[macro_export]
 macro_rules! node {
     ([$($token:tt)*]) => {
@@ -70,7 +75,9 @@ macro_rules! node {
     };
 }
 
-/// [`node!`] macro for [`ArcNode`].
+/// Create [`ArcNode`] items literally.
+///
+/// The API is same as [`node!`] macro.
 #[macro_export]
 macro_rules! node_arc {
     ([$($token:tt)*]) => {
@@ -118,11 +125,34 @@ macro_rules! yaml_map {
         $crate::Yaml::Map($crate::Map::new())
     };
     ($k1:expr => $v1:expr $(, $k2:expr => $v2:expr)* $(,)?) => {{
-        use std::iter::FromIterator;
+        use core::iter::FromIterator;
         $crate::Yaml::from_iter(vec![($k1, $v1) $(, ($k2, $v2))*])
     }};
 }
 
+/// Create a custom anchor visitor.
+///
+/// The anchor name should implement [`alloc::string::ToString`] trait.
+///
+/// ```
+/// use yaml_peg::{node, anchors};
+/// let v = anchors![
+///     "my-boss" => node!({node!("name") => node!("Henry")}),
+/// ];
+/// assert_eq!(v["my-boss"]["name"], node!("Henry"));
+/// ```
+#[macro_export]
+macro_rules! anchors {
+    () => {
+        $crate::AnchorBase::new()
+    };
+    ($k1:expr => $v1:expr $(, $k2:expr => $v2:expr)* $(,)?) => {{
+        use core::iter::FromIterator;
+        $crate::AnchorBase::from_iter(vec![($k1.to_string(), $v1) $(, ($k2.to_string(), $v2))*])
+    }};
+}
+
+mod anchors;
 pub mod dumper;
 mod indicator;
 mod node;
@@ -130,5 +160,4 @@ pub mod parser;
 pub mod repr;
 #[cfg(test)]
 mod tests;
-mod visitor;
 mod yaml;
