@@ -1,5 +1,6 @@
-use crate::*;
-use std::{
+use crate::{repr::*, *};
+use alloc::string::ToString;
+use core::{
     fmt::{Debug, Formatter, Result as FmtResult},
     hash::Hash,
     ops::Index,
@@ -7,13 +8,13 @@ use std::{
 };
 
 macro_rules! as_method {
-    {$(#[$meta:meta])* fn $id:ident = $ty:ident$(($op:tt))?
+    {$(#[$meta:meta])* fn $id:ident = $ty:ident$(($op:ident))?
         $(| ($default:expr)?)?
         $(| $ty2:ident)* -> $r:ty} => {
         $(#[$meta])*
         pub fn $id(&self) -> Result<$r, u64> {
             match self.yaml() {
-                YamlBase::$ty(v) $(| YamlBase::$ty2(v))* => Ok($($op)?v),
+                YamlBase::$ty(v) $(| YamlBase::$ty2(v))* => Ok(v$(.$op())?),
                 $(YamlBase::Null => Ok($default),)?
                 _ => Err(self.pos()),
             }
@@ -39,10 +40,10 @@ macro_rules! as_num_method {
     };
 }
 
-/// A node with [`std::rc::Rc`] holder.
-pub type Node = NodeBase<repr::RcRepr>;
-/// A node with [`std::sync::Arc`] holder.
-pub type ArcNode = NodeBase<repr::ArcRepr>;
+/// A node with [`alloc::rc::Rc`] holder.
+pub type Node = NodeBase<RcRepr>;
+/// A node with [`alloc::sync::Arc`] holder.
+pub type ArcNode = NodeBase<ArcRepr>;
 
 /// Readonly node, including line number, column number, type assertion and anchor.
 /// You can access [`YamlBase`] type through [`NodeBase::yaml`] method.
@@ -59,17 +60,27 @@ pub type ArcNode = NodeBase<repr::ArcRepr>;
 /// assert_eq!(s.len(), 1);
 /// ```
 ///
-/// There is a convenient macro [`node!`] to create nodes literally.
+/// There is also a convenient macro [`node!`] to create nodes literally.
+/// Please see the macro description for more information.
 ///
-/// Nodes can be indexing by `usize` or `&str`,
-/// but it will always return self if the index is not contained.
+/// Nodes can be indexing by convertable values, or array indicator [`Ind`],
+/// but it will be panic if the index is not contained.
 ///
 /// ```
-/// use yaml_peg::node;
+/// use yaml_peg::{node, Ind};
+/// let n = node!([node!("a"), node!("b"), node!("c")]);
+/// assert_eq!(node!("b"), n[Ind(1)]);
+/// ```
+///
+/// ```should_panic
+/// use yaml_peg::{node, Ind};
 /// let n = node!(null);
-/// assert_eq!(n["a"][0]["bc"], n);
+/// let n = &n["a"][Ind(0)]["b"];
 /// ```
 ///
+/// Same as containers, to prevent panic, the [`NodeBase::get`] method is the best choice.
+/// The [`NodeBase::get_default`] can provide missing key value when indexing.
+///
 /// There are `as_*` methods provide `Result<T, u64>` returns with node position,
 /// default options can be created by [`Result::unwrap_or`],
 /// additional error message can be attach by [`Result::map_err`],
@@ -83,7 +94,7 @@ pub type ArcNode = NodeBase<repr::ArcRepr>;
 ///     let n = node!({
 ///         node!("title") => node!(12.)
 ///     });
-///     let n = n.get(&["title"]).map_err(|p| ("missing \"title\"", p))?;
+///     let n = n.get("title").map_err(|p| ("missing \"title\"", p))?;
 ///     assert_eq!(
 ///         Err(("title", 0)),
 ///         n.as_str().map_err(|p| ("title", p))
@@ -96,51 +107,63 @@ pub type ArcNode = NodeBase<repr::ArcRepr>;
 /// }
 /// ```
 ///
-/// For default value on map type, [`NodeBase::get`] method has a shorten method [`NodeBase::get_default`] to combining
-/// transform function and default function as well.
+/// # Anchor
+///
+/// The anchors can be infer from [`AnchorBase`], and attach with [`NodeBase::as_anchor`] method.
 ///
 /// # Clone
 ///
-/// Since the YAML data is wrapped by reference counter [`std::rc::Rc`] and [`std::sync::Arc`],
+/// Since the YAML data is wrapped by reference counter [`alloc::rc::Rc`] and [`alloc::sync::Arc`],
 /// cloning node just increase the reference counter,
 /// the entire data structure are still shared together.
 ///
+/// ```
+/// use std::rc::Rc;
+/// use yaml_peg::node;
+/// let a = node!("a");
+/// {
+///     let b = a.clone();
+///     assert_eq!(2, Rc::strong_count(b.as_ref()));
+/// }
+/// assert_eq!(1, Rc::strong_count(a.as_ref()));
+/// ```
+///
 /// If you want to copy data, please get the data first.
 #[derive(Hash, Eq, PartialEq, Clone)]
-pub struct NodeBase<R: repr::Repr>(R);
+pub struct NodeBase<R: Repr>(pub(crate) R);
 
-impl<Repr: repr::Repr> NodeBase<Repr> {
+impl<R: Repr> NodeBase<R> {
     /// Create node from YAML data.
-    pub fn new(yaml: YamlBase<Repr>, pos: u64, ty: &str, anchor: &str) -> Self {
-        Self(Repr::repr(yaml, pos, ty.to_owned(), anchor.to_owned()))
+    pub fn new(yaml: YamlBase<R>, pos: u64, ty: &str, anchor: &str) -> Self {
+        Self(R::repr(yaml, pos, ty.to_string(), anchor.to_string()))
     }
 
     /// Document position.
     #[inline(always)]
     pub fn pos(&self) -> u64 {
-        self.0.pos()
+        self.0.as_ref().pos
     }
 
     /// Type assertion.
     #[inline(always)]
     pub fn ty(&self) -> &str {
-        self.0.ty()
+        &self.0.as_ref().ty
     }
 
     /// Anchor reference.
     #[inline(always)]
     pub fn anchor(&self) -> &str {
-        self.0.anchor()
+        &self.0.as_ref().anchor
     }
 
     /// YAML data.
     #[inline(always)]
-    pub fn yaml(&self) -> &YamlBase<Repr> {
-        self.0.yaml()
+    pub fn yaml(&self) -> &YamlBase<R> {
+        &self.0.as_ref().yaml
     }
 
     /// Drop the node and get the YAML data.
-    pub fn into_yaml(self) -> YamlBase<Repr> {
+    pub fn into_yaml(self) -> YamlBase<R> {
         self.0.into_yaml()
     }
 
@@ -156,7 +179,7 @@ impl<Repr: repr::Repr> NodeBase<Repr> {
         /// use yaml_peg::{node};
         /// assert!(node!(true).as_bool().unwrap());
         /// ```
-        fn as_bool = Bool(*) -> bool
+        fn as_bool = Bool(clone) -> bool
     }
 
     as_num_method! {
@@ -227,77 +250,77 @@ impl<Repr: repr::Repr> NodeBase<Repr> {
         }
     }
 
-    as_method! {
-        /// Convert to the string pointer of an anchor.
-        ///
-        /// ```
-        /// use yaml_peg::node;
-        /// assert_eq!("abc", node!(*("abc")).as_anchor().unwrap());
-        /// ```
-        fn as_anchor = Anchor -> &str
+    /// Infer an anchor with anchor visitor.
+    ///
+    /// If the node is not a anchor, or the anchor does not exist, the original node is returned.
+    /// Since the anchor type is invalid except for this method, missing anchor will still return an error.
+    ///
+    /// ```
+    /// use yaml_peg::{node, anchors};
+    /// let node_a = node!(*"a");
+    /// let v = anchors!["a" => node!(20.)];
+    /// assert_eq!(20., node_a.as_anchor(&v).as_float().unwrap());
+    /// ```
+    pub fn as_anchor(&self, anchors: &AnchorBase<R>) -> Self {
+        match self.yaml() {
+            YamlBase::Anchor(s) if anchors.contains_key(s) => anchors.get(s).unwrap().clone(),
+            _ => self.clone(),
+        }
     }
 
     as_method! {
-        /// Convert to array.
-        ///
-        /// WARNING: The object ownership will be took.
+        /// Convert to array. The object ownership will be took.
         ///
         /// ```
         /// use yaml_peg::node;
-        /// assert_eq!(
-        ///     &vec![node!(1), node!(2)],
-        ///     node!([node!(1), node!(2)]).as_array().unwrap()
-        /// );
+        /// let n = node!([node!(1), node!(2)]);
+        /// assert_eq!(&vec![node!(1), node!(2)], n.as_array().unwrap());
+        /// let n = node!([node!("55")]);
+        /// for n in n.as_array().unwrap() {
+        ///     assert_eq!(&node!("55"), n);
+        /// }
         /// ```
-        fn as_array = Array -> &Array<Repr>
+        fn as_array = Array -> &Array<R>
     }
 
     as_method! {
-        /// Convert to map.
-        ///
-        /// WARNING: The object ownership will be took.
+        /// Convert to map. The object ownership will be took.
         ///
         /// ```
         /// use yaml_peg::node;
-        /// assert_eq!(
-        ///     &node!(2),
-        ///     node!({node!(1) => node!(2)}).as_map().unwrap().get(&node!(1)).unwrap()
-        /// );
+        /// let n = node!({node!(1) => node!(2)});
+        /// assert_eq!(node!(2), n.as_map().unwrap()[&node!(1)]);
+        /// for (k, v) in n.as_map().unwrap() {
+        ///     assert_eq!(&node!(1), k);
+        ///     assert_eq!(&node!(2), v);
+        /// }
         /// ```
-        fn as_map = Map -> &Map<Repr>
+        fn as_map = Map -> &Map<R>
     }
 
-    /// Convert to map and try to get the value by keys recursivly.
+    /// Convert to map and try to get the value by key.
     ///
     /// If any key is missing, return `Err` with node position.
     ///
     /// ```
+    /// # fn main() -> Result<(), u64> {
     /// use yaml_peg::node;
-    /// assert_eq!(
-    ///     &node!(30.),
-    ///     node!({node!("a") => node!({node!("b") => node!(30.)})}).get(&["a", "b"]).unwrap()
-    /// );
+    /// let n = node!({node!("a") => node!({node!("b") => node!(30.)})});
+    /// assert_eq!(node!(30.), n.get("a")?.get("b")?);
+    /// # Ok::<(), u64>(()) }
     /// ```
-    pub fn get<Y>(&self, keys: &[Y]) -> Result<&Self, u64>
+    pub fn get<Y>(&self, keys: Y) -> Result<Self, u64>
     where
-        Y: Into<YamlBase<Repr>> + Copy,
+        Y: Into<Self> + Copy,
     {
-        if keys.is_empty() {
-            panic!("invalid search!");
-        }
-        match self.yaml() {
-            YamlBase::Map(m) => {
-                if let Some(n) = m.get(&Self::from(keys[0].into())) {
-                    if keys[1..].is_empty() {
-                        Ok(n)
-                    } else {
-                        n.get(&keys[1..])
-                    }
-                } else {
-                    Err(self.pos())
-                }
+        if let YamlBase::Map(m) = self.yaml() {
+            if let Some(n) = m.get(&keys.into()) {
+                Ok(n.clone())
+            } else {
+                Err(self.pos())
             }
-            _ => Err(self.pos()),
+        } else {
+            Err(self.pos())
         }
     }
 
@@ -309,82 +332,112 @@ impl<Repr: repr::Repr> NodeBase<Repr> {
     /// + If the value is not exist, return the default value.
     ///
     /// ```
+    /// # fn main() -> Result<(), u64> {
     /// use yaml_peg::{node, NodeBase};
     /// let a = node!({node!("a") => node!({node!("b") => node!("c")})});
     /// assert_eq!(
     ///     "c",
-    ///     a.get_default(&["a", "b"], "d", NodeBase::as_str).unwrap()
+    ///     a.get("a")?.get_default("b", "d", NodeBase::as_str)?
     /// );
     /// let b = node!({node!("a") => node!({})});
     /// assert_eq!(
     ///     "d",
-    ///     b.get_default(&["a", "b"], "d", NodeBase::as_str).unwrap()
+    ///     b.get("a")?.get_default("b", "d", NodeBase::as_str)?
     /// );
     /// let c = node!({node!("a") => node!({node!("b") => node!(20.)})});
     /// assert_eq!(
     ///     Err(0),
-    ///     c.get_default(&["a", "b"], "d", NodeBase::as_str)
+    ///     c.get("a")?.get_default("b", "d", NodeBase::as_str)
     /// );
+    /// # Ok::<(), u64>(()) }
     /// ```
-    pub fn get_default<'a, Y, R, F>(&'a self, keys: &[Y], default: R, factory: F) -> Result<R, u64>
+    pub fn get_default<'a, Y, Ret, F>(
+        &'a self,
+        keys: Y,
+        default: Ret,
+        factory: F,
+    ) -> Result<Ret, u64>
     where
-        Y: Into<YamlBase<Repr>> + Copy,
-        F: Fn(&'a Self) -> Result<R, u64>,
+        Y: Into<Self> + Copy,
+        F: Fn(&'a Self) -> Result<Ret, u64>,
     {
-        if keys.is_empty() {
-            panic!("invalid search!");
-        }
-        match self.yaml() {
-            YamlBase::Map(m) => {
-                if let Some(n) = m.get(&Self::from(keys[0].into())) {
-                    if keys[1..].is_empty() {
-                        factory(n)
-                    } else {
-                        n.get_default(&keys[1..], default, factory)
-                    }
-                } else {
-                    Ok(default)
-                }
+        if let YamlBase::Map(m) = self.yaml() {
+            if let Some(n) = m.get(&keys.into()) {
+                factory(n)
+            } else {
+                Ok(default)
             }
-            _ => Err(self.pos()),
+        } else {
+            Err(self.pos())
+        }
+    }
+
+    /// Get node through index indicator. Only suitable for array.
+    ///
+    /// ```
+    /// # fn main() -> Result<(), u64> {
+    /// use yaml_peg::{node, Ind};
+    /// let n = node!([node!("a"), node!("b"), node!("c")]);
+    /// assert_eq!(node!("b"), n.get_ind(Ind(1))?);
+    /// # Ok::<(), u64>(()) }
+    /// ```
+    pub fn get_ind(&self, ind: Ind) -> Result<Self, u64> {
+        if let YamlBase::Array(a) = self.yaml() {
+            if let Some(n) = a.get(ind.0) {
+                Ok(n.clone())
+            } else {
+                Err(self.pos())
+            }
+        } else {
+            Err(self.pos())
         }
     }
 }
 
-impl<R: repr::Repr> Debug for NodeBase<R> {
-    fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
+impl<R: Repr> Debug for NodeBase<R> {
+    fn fmt(&self, f: &mut Formatter) -> FmtResult {
         f.write_fmt(format_args!("Node{:?}", &self.0))
     }
 }
 
-impl<R: repr::Repr> Index<usize> for NodeBase<R> {
+/// Node index indicator use to indicate array position.
+pub struct Ind(pub usize);
+
+impl<R: Repr> Index<Ind> for NodeBase<R> {
     type Output = Self;
 
-    fn index(&self, index: usize) -> &Self::Output {
-        match self.yaml() {
-            YamlBase::Array(a) => a.get(index).unwrap_or(self),
-            YamlBase::Map(m) => m
-                .get(&Self::from(YamlBase::Int(index.to_string())))
-                .unwrap_or(self),
-            _ => self,
-        }
-    }
-}
-
-impl<R: repr::Repr> Index<&str> for NodeBase<R> {
-    type Output = Self;
-
-    fn index(&self, index: &str) -> &Self::Output {
-        if let YamlBase::Map(m) = self.yaml() {
-            m.get(&Self::from(YamlBase::from(index))).unwrap_or(self)
+    fn index(&self, index: Ind) -> &Self::Output {
+        if let YamlBase::Array(a) = self.yaml() {
+            a.index(index.0)
         } else {
-            self
+            panic!("out of bound!")
         }
     }
 }
 
-impl<R: repr::Repr> From<YamlBase<R>> for NodeBase<R> {
-    fn from(yaml: YamlBase<R>) -> Self {
-        Self::new(yaml, 0, "", "")
+impl<R, I> Index<I> for NodeBase<R>
+where
+    R: Repr,
+    I: Into<Self>,
+{
+    type Output = Self;
+
+    fn index(&self, index: I) -> &Self::Output {
+        if let YamlBase::Map(m) = self.yaml() {
+            m.get(&index.into())
+                .unwrap_or_else(|| panic!("out of bound!"))
+        } else {
+            panic!("out of bound!")
+        }
+    }
+}
+
+impl<R, Y> From<Y> for NodeBase<R>
+where
+    R: Repr,
+    Y: Into<YamlBase<R>>,
+{
+    fn from(yaml: Y) -> Self {
+        Self::new(yaml.into(), 0, "", "")
     }
 }
