@@ -3,7 +3,8 @@ pub use self::error::*;
 pub use self::grammar::*;
 pub use self::kernel::*;
 use crate::*;
-use std::iter::FromIterator;
+use alloc::{string::String, vec};
+use core::iter::FromIterator;
 
 mod error;
 mod grammar;
@@ -326,7 +327,7 @@ impl<R: repr::Repr> Parser<'_, R> {
 macro_rules! impl_parser {
     ($(#[$meta:meta])* $func:ident -> $repr:ty) => {
         $(#[$meta])*
-        pub fn $func(doc: &str) -> Result<(Array<$repr>, AnchorVisitor<$repr>), String> {
+        pub fn $func(doc: &str) -> Result<(Array<$repr>, AnchorBase<$repr>), String> {
             let mut p = Parser::<$repr>::new(doc.as_bytes());
             p.parse()
                 .map_err(|e| e.into_error(doc))
@@ -336,7 +337,7 @@ macro_rules! impl_parser {
 }
 
 impl_parser! {
-    /// Parse YAML document into [`std::rc::Rc`] data holder.
+    /// Parse YAML document into [`alloc::rc::Rc`] data holder.
     /// Return an array of nodes and the anchors.
     ///
     /// ```
@@ -349,7 +350,7 @@ impl_parser! {
 }
 
 impl_parser! {
-    /// Parse YAML document into [`std::sync::Arc`] data holder.
+    /// Parse YAML document into [`alloc::sync::Arc`] data holder.
     /// Return an array of nodes and the anchors.
     ///
     /// ```
